@@ -13,8 +13,3 @@
 #' @aliases LinkedMatrix-package
 #' @import methods
 NULL
-
-
-release_questions <- function() {
-    c("Have you updated the NEWS file?")
-}
